import React, { Component } from 'react'
import {
    Text,
    TouchableOpacity,
    View,
    TextInput
} from 'react-native'
import styles from './styles'
import CardView from 'react-native-cardview'
import PropTypes from 'prop-types'

export default class Login extends Component {

    static propTypes = {
        onSubmitButton: PropTypes.func,
        onChangeEmail: PropTypes.func,
        onChangePassword: PropTypes.func,
    }
    static defaultProps = {
        onSubmitButton: () => {},
        onChangeEmail: () => {},
        onChangePassword: () => {}
    }
    constructor(props) {
        super(props)
        this.state = {
            email: "",
            password: ""
        }
    }

    _onChangeEmail = value => {
        const { onChangeEmail } = this.props;
        if (onChangeEmail) {
            onChangeEmail(value);
        }
        this.setState({ email: value });
    };
    _onChangePassword = value => {
        const { onChangePassword } = this.props;
        if (onChangePassword) {
            onChangePassword(value);
        }
        this.setState({ password: value });
    };

    _onSubmit = () => {
        const { onSubmitButton } = this.props;
        if (onSubmitButton) {
            onSubmitButton();
        }
    }
    render() {
        const { input, container, headerText, loginButton } = styles
        return (
            <View style={container}>

                <Text style={headerText}>DevNet</Text>

                <CardView
                    margin={20}
                    padding={20}
                    cardElevation={2}
                    cardMaxElevation={2}
                    cornerRadius={5}>

                    <TextInput value={this.state.email} style={input} placeholder="email" onChangeText={this._onChangeEmail} keyboardType="email-address" />
                    <TextInput style={input} placeholder="Password" secureTextEntry={true} onChangeText={this._onChangePassword} />

                    <TouchableOpacity onPress={this._onSubmit}>
                        <View
                            style={loginButton}>
                            <Text style={{ color: 'white', fontSize: 20, fontWeight: '800' }}>
                                Login
                        </Text>
                        </View>
                    </TouchableOpacity>

                    <Text style={styles.footerText}> Don't you have an account? <Text style={styles.footerLink}>Register here!</Text></Text>

                </CardView>
            </View>
        )
    }
}
