import React, { Component } from 'react'
import {
    Text,
    View,
    ScrollView,
    StatusBar,
    Modal,
    TouchableOpacity,
    Image
} from 'react-native'
import itemJson from './items.json'
import { Button } from 'react-native-elements'
import Icon from 'react-native-vector-icons/FontAwesome'
import MultiSelect from 'react-native-multiple-select'
import styles from './styles'
import PropTypes from 'prop-types'

const items = itemJson
export default class Profile extends Component {
    static propTypes = {
        email: PropTypes.string,
        isCurrentUser: PropTypes.bool,
        isConnected: PropTypes.bool
    }
    static defaultProps = {
        email: "",
        isCurrentUser: null,
        isConnected: null
    }
    constructor(props) {
        super(props)
        this.state = {
            modalVisible: false,
            buttonText: "Connect",
            selectedItems: []
        }
    }
    renderConnectBtn() {
        const { isCurrentUser, isConnected } = this.props
        var buttonText = ""
        if (isCurrentUser)
            buttonText = "Edit"
        else if(isConnected) 
            buttonText = "Disconnect"
        else
            buttonText = "Connect"

        return (
            <Button
                onPress={() => {
                    if (this.props.isCurrentUser) {
                        this.editProfile()
                    }
                    else if (this.props.isConnected) {
                        this.disconnectUser()
                    }
                    else {
                        this.connectUser()
                    }
                }}
                raised={true}
                type='solid'
                title={buttonText}
            />)
    }

    connectUser() {
        this.setModalVisible(true)
    }

    setModalVisible(visible) {
        this.setState({ modalVisible: visible });
    }

    onSelectedItemsChange = selectedItems => {
        // console.log(selectedItems)
        this.setState({ selectedItems: selectedItems });
    };

    renderModelBox() {

        const {
            DP_Modal_Container,
            DP_Modal_Content,
            DP_Modal_Header,
            DP_Modal_Description } = styles
        return (
            //  Modal for Relation
            <Modal
                animationType="slide"
                transparent={true}
                visible={this.state.modalVisible}
                onRequestClose={() => this.setModalVisible(!this.state.modalVisible)}>
                <View style={DP_Modal_Container}>
                    <View style={DP_Modal_Content}>
                        <View style={DP_Modal_Header}>
                            <Text style={{ fontSize: 20, fontWeight: 'bold', color: 'white' }}>
                                Confirm Relations
                                </Text>
                            <TouchableOpacity onPress={() => this.setModalVisible(false)}>
                                <Icon
                                    name="times"
                                    size={25}
                                    color="white"
                                    style={{ paddingEnd: 15 }}
                                />
                            </TouchableOpacity>
                        </View>
                        <View style={DP_Modal_Description}>
                            <Text style={{ fontSize: 15 }}>
                                Choose your relation with him/her!
                                </Text>
                        </View>
                        <MultiSelect
                            items={items}
                            uniqueKey="name"
                            ref={(component) => { this.multiSelect = component }}
                            onSelectedItemsChange={this.onSelectedItemsChange}
                            selectedItems={this.state.selectedItems}
                            selectText="Choose relation"
                            searchInputPlaceholderText="Search Items..."
                            onChangeInput={(text) => console.log(text)}
                            altFontFamily="ProximaNova-Light"
                            tagRemoveIconColor="#CCC"
                            tagBorderColor="#29B6F6"
                            tagTextColor="#CCC"
                            selectedItemTextColor="#CCC"
                            selectedItemIconColor="#29B6F6"
                            itemTextColor="#000"
                            displayKey="name"
                            searchInputStyle={{ color: '#CCC' }}
                            hideSubmitButton
                        />
                        <View style={{ width: 200, alignSelf: 'center', margin: 20 }}>
                            <Button
                                raised={true}
                                type='solid'
                                title='Confirm'
                                onPress={() => this.addConnection()}
                                buttonStyle={{ backgroundColor: '#66b3ff' }}
                            />
                        </View>
                    </View>
                </View>
            </Modal>
        )
    }
    render() {
        const { DP_container,
            DP_head,
            DP_profilePic,
            DP_profile_description,
            DP_name,
            DP_email,
            DP_detail_container,
            DP_detail,
            DP_detail_data } = styles
        return (
            <ScrollView style={DP_container}>
                <StatusBar backgroundColor="orange" barStyle="light-content" />
                {this.renderModelBox()}
                <View style={DP_head}>
                    <Image style={DP_profilePic} source={require('./man.png')} />
                    <View style={DP_profile_description}>
                        <Text style={DP_name}>name</Text>
                        <Text style={DP_email}>{this.props.email}</Text>
                        <View style={{ width: '99%', alignSelf: 'center' }}>
                            {this.renderConnectBtn()}
                        </View>
                    </View>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Age</Text>
                    <Text style={DP_detail_data}>Age</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Date of birth</Text>
                    <Text style={DP_detail_data}>dob</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Gender</Text>
                    <Text style={DP_detail_data}>gender</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Job</Text>
                    <Text style={DP_detail_data}>job</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Address</Text>
                    <Text style={DP_detail_data}>.address</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Phone</Text>
                    <Text style={DP_detail_data}>phone</Text>
                </View>
                <View style={DP_detail_container}>
                    <Text style={DP_detail}>Work At</Text>
                    <Text style={DP_detail_data}>workAt}</Text>
                </View>
            </ScrollView>
        )
    }
}